package com.qmth.cqb.paper.web;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import cn.com.qmth.examcloud.common.uac.entity.AccessUser;

import com.qmth.cqb.paper.dao.PaperStructBlueprintRepo;
import com.qmth.cqb.paper.dto.PaperStructBlueprintDto;
import com.qmth.cqb.paper.model.PaperStructBlueprint;
import com.qmth.cqb.paper.service.PaperStructBlueprintService;

/**
 * @describle 蓝图试卷结构controller
 * @author weiwenhai
 * @date   2017.11.17
 */
@Controller
@RequestMapping("${api_cqb}/")
public class PaperStructBlueprintController {
	
	@Autowired
	private PaperStructBlueprintService paperStructBlueprintService;
	
	@Autowired
	private PaperStructBlueprintRepo paperStructBlueprintRepo;

	@ApiOperation(value="查询所有蓝图试卷结构", notes="带分页")
	@GetMapping(value="/paperStructBlueprint/all/{curPage}/{pageSize}")
	public ResponseEntity<Object> findAll(@ModelAttribute PaperStructBlueprintDto paperStructBlueprintDto,
										  @PathVariable Integer curPage,
										  @PathVariable Integer pageSize,
										  HttpServletRequest request){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser == null){
			 return new ResponseEntity(HttpStatus.NOT_FOUND);
		 }
		paperStructBlueprintDto.setOrgId(accessUser.getRootOrgId());
		Page<PaperStructBlueprint> paperStructBlueprintPage = paperStructBlueprintService.findAll(paperStructBlueprintDto, new PageRequest(curPage-1, pageSize));
		return new ResponseEntity<Object>(paperStructBlueprintPage,HttpStatus.OK);
	}
	
	@ApiOperation(value="保存试卷结构", notes="保存试卷结构")
	@PostMapping(value="/paperStructBlueprint/save/{ids}")
	public ResponseEntity<Object> saveSingle(HttpServletRequest request, @PathVariable String ids, @RequestBody PaperStructBlueprintDto paperStructBlueprintDto){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser != null){
			paperStructBlueprintDto.setCreator(accessUser.getName());
			paperStructBlueprintDto.setOrgId(accessUser.getRootOrgId());
			paperStructBlueprintService.saveSingle(paperStructBlueprintDto, ids);
			return new ResponseEntity<Object>(HttpStatus.OK);
		}
		return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
	}
	
	@ApiOperation(value="根据id查询试卷结构", notes="根据id查询试卷结构")
	@GetMapping(value="/paperStructBlueprint/findOne/{id}")
	public ResponseEntity<Object> findOne(HttpServletRequest request,@PathVariable Long id){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser != null){
			PaperStructBlueprint paperStructBlueprint = paperStructBlueprintRepo.findOne(id);
			return new ResponseEntity<Object>(paperStructBlueprint,HttpStatus.OK);
		}
		return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
	}
	
	@ApiOperation(value="根据id删除试卷结构", notes="根据id删除试卷结构")
	@DeleteMapping(value="/paperStructBlueprint/delete/{id}")
	public ResponseEntity<Object> deleteSingle(HttpServletRequest request,@PathVariable Long id){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser != null){
			paperStructBlueprintService.deleteSingle(id);
			return new ResponseEntity<Object>(HttpStatus.OK);
		}
		return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
	}
	
	@ApiOperation(value="根据课程代码查询试卷结构", notes="根据课程代码查询试卷结构")
	@GetMapping(value="/paperStructBlueprint/findByCourseNo/{courseNo}")
	public ResponseEntity<Object> findByCourseNo(HttpServletRequest request, @PathVariable String courseNo){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser != null){
			List<PaperStructBlueprint> paperStructBlueprints = paperStructBlueprintService.findByCourseNo(courseNo);
			return new ResponseEntity<Object>(paperStructBlueprints,HttpStatus.OK);
		}
		return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
	}
}
